# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.models_category_hook import ModelsCategoryHook


class ModelsAddInboxCategoryRequest(Model):
    """Models add inbox category request (models.AddInboxCategoryRequest)

    Properties:
        enabled: (enabled) REQUIRED bool

        expires_in: (expiresIn) REQUIRED int

        name: (name) REQUIRED str

        save_inbox: (saveInbox) REQUIRED bool

        send_notification: (sendNotification) REQUIRED bool

        hook: (hook) OPTIONAL ModelsCategoryHook

        json_schema: (jsonSchema) OPTIONAL Dict[str, Any]
    """

    # region fields

    enabled: bool  # REQUIRED
    expires_in: int  # REQUIRED
    name: str  # REQUIRED
    save_inbox: bool  # REQUIRED
    send_notification: bool  # REQUIRED
    hook: ModelsCategoryHook  # OPTIONAL
    json_schema: Dict[str, Any]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_enabled(self, value: bool) -> ModelsAddInboxCategoryRequest:
        self.enabled = value
        return self

    def with_expires_in(self, value: int) -> ModelsAddInboxCategoryRequest:
        self.expires_in = value
        return self

    def with_name(self, value: str) -> ModelsAddInboxCategoryRequest:
        self.name = value
        return self

    def with_save_inbox(self, value: bool) -> ModelsAddInboxCategoryRequest:
        self.save_inbox = value
        return self

    def with_send_notification(self, value: bool) -> ModelsAddInboxCategoryRequest:
        self.send_notification = value
        return self

    def with_hook(self, value: ModelsCategoryHook) -> ModelsAddInboxCategoryRequest:
        self.hook = value
        return self

    def with_json_schema(self, value: Dict[str, Any]) -> ModelsAddInboxCategoryRequest:
        self.json_schema = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "enabled"):
            result["enabled"] = bool(self.enabled)
        elif include_empty:
            result["enabled"] = False
        if hasattr(self, "expires_in"):
            result["expiresIn"] = int(self.expires_in)
        elif include_empty:
            result["expiresIn"] = 0
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "save_inbox"):
            result["saveInbox"] = bool(self.save_inbox)
        elif include_empty:
            result["saveInbox"] = False
        if hasattr(self, "send_notification"):
            result["sendNotification"] = bool(self.send_notification)
        elif include_empty:
            result["sendNotification"] = False
        if hasattr(self, "hook"):
            result["hook"] = self.hook.to_dict(include_empty=include_empty)
        elif include_empty:
            result["hook"] = ModelsCategoryHook()
        if hasattr(self, "json_schema"):
            result["jsonSchema"] = {str(k0): v0 for k0, v0 in self.json_schema.items()}
        elif include_empty:
            result["jsonSchema"] = {}
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        enabled: bool,
        expires_in: int,
        name: str,
        save_inbox: bool,
        send_notification: bool,
        hook: Optional[ModelsCategoryHook] = None,
        json_schema: Optional[Dict[str, Any]] = None,
        **kwargs,
    ) -> ModelsAddInboxCategoryRequest:
        instance = cls()
        instance.enabled = enabled
        instance.expires_in = expires_in
        instance.name = name
        instance.save_inbox = save_inbox
        instance.send_notification = send_notification
        if hook is not None:
            instance.hook = hook
        if json_schema is not None:
            instance.json_schema = json_schema
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsAddInboxCategoryRequest:
        instance = cls()
        if not dict_:
            return instance
        if "enabled" in dict_ and dict_["enabled"] is not None:
            instance.enabled = bool(dict_["enabled"])
        elif include_empty:
            instance.enabled = False
        if "expiresIn" in dict_ and dict_["expiresIn"] is not None:
            instance.expires_in = int(dict_["expiresIn"])
        elif include_empty:
            instance.expires_in = 0
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "saveInbox" in dict_ and dict_["saveInbox"] is not None:
            instance.save_inbox = bool(dict_["saveInbox"])
        elif include_empty:
            instance.save_inbox = False
        if "sendNotification" in dict_ and dict_["sendNotification"] is not None:
            instance.send_notification = bool(dict_["sendNotification"])
        elif include_empty:
            instance.send_notification = False
        if "hook" in dict_ and dict_["hook"] is not None:
            instance.hook = ModelsCategoryHook.create_from_dict(
                dict_["hook"], include_empty=include_empty
            )
        elif include_empty:
            instance.hook = ModelsCategoryHook()
        if "jsonSchema" in dict_ and dict_["jsonSchema"] is not None:
            instance.json_schema = {
                str(k0): v0 for k0, v0 in dict_["jsonSchema"].items()
            }
        elif include_empty:
            instance.json_schema = {}
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsAddInboxCategoryRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsAddInboxCategoryRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsAddInboxCategoryRequest,
        List[ModelsAddInboxCategoryRequest],
        Dict[Any, ModelsAddInboxCategoryRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "enabled": "enabled",
            "expiresIn": "expires_in",
            "name": "name",
            "saveInbox": "save_inbox",
            "sendNotification": "send_notification",
            "hook": "hook",
            "jsonSchema": "json_schema",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "enabled": True,
            "expiresIn": True,
            "name": True,
            "saveInbox": True,
            "sendNotification": True,
            "hook": False,
            "jsonSchema": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsMessageStats(Model):
    """Models message stats (models.MessageStats)

    Properties:
        id_: (id) REQUIRED str

        message_read: (messageRead) REQUIRED int

        message_stored: (messageStored) REQUIRED int

        notification_sent: (notificationSent) REQUIRED int
    """

    # region fields

    id_: str  # REQUIRED
    message_read: int  # REQUIRED
    message_stored: int  # REQUIRED
    notification_sent: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_id(self, value: str) -> ModelsMessageStats:
        self.id_ = value
        return self

    def with_message_read(self, value: int) -> ModelsMessageStats:
        self.message_read = value
        return self

    def with_message_stored(self, value: int) -> ModelsMessageStats:
        self.message_stored = value
        return self

    def with_notification_sent(self, value: int) -> ModelsMessageStats:
        self.notification_sent = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "message_read"):
            result["messageRead"] = int(self.message_read)
        elif include_empty:
            result["messageRead"] = 0
        if hasattr(self, "message_stored"):
            result["messageStored"] = int(self.message_stored)
        elif include_empty:
            result["messageStored"] = 0
        if hasattr(self, "notification_sent"):
            result["notificationSent"] = int(self.notification_sent)
        elif include_empty:
            result["notificationSent"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        id_: str,
        message_read: int,
        message_stored: int,
        notification_sent: int,
        **kwargs,
    ) -> ModelsMessageStats:
        instance = cls()
        instance.id_ = id_
        instance.message_read = message_read
        instance.message_stored = message_stored
        instance.notification_sent = notification_sent
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsMessageStats:
        instance = cls()
        if not dict_:
            return instance
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "messageRead" in dict_ and dict_["messageRead"] is not None:
            instance.message_read = int(dict_["messageRead"])
        elif include_empty:
            instance.message_read = 0
        if "messageStored" in dict_ and dict_["messageStored"] is not None:
            instance.message_stored = int(dict_["messageStored"])
        elif include_empty:
            instance.message_stored = 0
        if "notificationSent" in dict_ and dict_["notificationSent"] is not None:
            instance.notification_sent = int(dict_["notificationSent"])
        elif include_empty:
            instance.notification_sent = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsMessageStats]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsMessageStats]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsMessageStats, List[ModelsMessageStats], Dict[Any, ModelsMessageStats]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "id": "id_",
            "messageRead": "message_read",
            "messageStored": "message_stored",
            "notificationSent": "notification_sent",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "id": True,
            "messageRead": True,
            "messageStored": True,
            "notificationSent": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.models_chat_snapshot_message import ModelsChatSnapshotMessage


class ModelsChatSnapshots(Model):
    """Models chat snapshots (models.ChatSnapshots)

    Properties:
        chat_id: (chatId) REQUIRED str

        created_at: (createdAt) REQUIRED int

        joined_topics: (joinedTopics) REQUIRED List[str]

        messages: (messages) REQUIRED List[ModelsChatSnapshotMessage]

        namespace: (namespace) REQUIRED str

        sender_id: (senderId) REQUIRED str

        ticket_id: (ticketId) REQUIRED str

        topic_id: (topicId) REQUIRED str
    """

    # region fields

    chat_id: str  # REQUIRED
    created_at: int  # REQUIRED
    joined_topics: List[str]  # REQUIRED
    messages: List[ModelsChatSnapshotMessage]  # REQUIRED
    namespace: str  # REQUIRED
    sender_id: str  # REQUIRED
    ticket_id: str  # REQUIRED
    topic_id: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_chat_id(self, value: str) -> ModelsChatSnapshots:
        self.chat_id = value
        return self

    def with_created_at(self, value: int) -> ModelsChatSnapshots:
        self.created_at = value
        return self

    def with_joined_topics(self, value: List[str]) -> ModelsChatSnapshots:
        self.joined_topics = value
        return self

    def with_messages(
        self, value: List[ModelsChatSnapshotMessage]
    ) -> ModelsChatSnapshots:
        self.messages = value
        return self

    def with_namespace(self, value: str) -> ModelsChatSnapshots:
        self.namespace = value
        return self

    def with_sender_id(self, value: str) -> ModelsChatSnapshots:
        self.sender_id = value
        return self

    def with_ticket_id(self, value: str) -> ModelsChatSnapshots:
        self.ticket_id = value
        return self

    def with_topic_id(self, value: str) -> ModelsChatSnapshots:
        self.topic_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "chat_id"):
            result["chatId"] = str(self.chat_id)
        elif include_empty:
            result["chatId"] = ""
        if hasattr(self, "created_at"):
            result["createdAt"] = int(self.created_at)
        elif include_empty:
            result["createdAt"] = 0
        if hasattr(self, "joined_topics"):
            result["joinedTopics"] = [str(i0) for i0 in self.joined_topics]
        elif include_empty:
            result["joinedTopics"] = []
        if hasattr(self, "messages"):
            result["messages"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.messages
            ]
        elif include_empty:
            result["messages"] = []
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "sender_id"):
            result["senderId"] = str(self.sender_id)
        elif include_empty:
            result["senderId"] = ""
        if hasattr(self, "ticket_id"):
            result["ticketId"] = str(self.ticket_id)
        elif include_empty:
            result["ticketId"] = ""
        if hasattr(self, "topic_id"):
            result["topicId"] = str(self.topic_id)
        elif include_empty:
            result["topicId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        chat_id: str,
        created_at: int,
        joined_topics: List[str],
        messages: List[ModelsChatSnapshotMessage],
        namespace: str,
        sender_id: str,
        ticket_id: str,
        topic_id: str,
        **kwargs,
    ) -> ModelsChatSnapshots:
        instance = cls()
        instance.chat_id = chat_id
        instance.created_at = created_at
        instance.joined_topics = joined_topics
        instance.messages = messages
        instance.namespace = namespace
        instance.sender_id = sender_id
        instance.ticket_id = ticket_id
        instance.topic_id = topic_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsChatSnapshots:
        instance = cls()
        if not dict_:
            return instance
        if "chatId" in dict_ and dict_["chatId"] is not None:
            instance.chat_id = str(dict_["chatId"])
        elif include_empty:
            instance.chat_id = ""
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = int(dict_["createdAt"])
        elif include_empty:
            instance.created_at = 0
        if "joinedTopics" in dict_ and dict_["joinedTopics"] is not None:
            instance.joined_topics = [str(i0) for i0 in dict_["joinedTopics"]]
        elif include_empty:
            instance.joined_topics = []
        if "messages" in dict_ and dict_["messages"] is not None:
            instance.messages = [
                ModelsChatSnapshotMessage.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["messages"]
            ]
        elif include_empty:
            instance.messages = []
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "senderId" in dict_ and dict_["senderId"] is not None:
            instance.sender_id = str(dict_["senderId"])
        elif include_empty:
            instance.sender_id = ""
        if "ticketId" in dict_ and dict_["ticketId"] is not None:
            instance.ticket_id = str(dict_["ticketId"])
        elif include_empty:
            instance.ticket_id = ""
        if "topicId" in dict_ and dict_["topicId"] is not None:
            instance.topic_id = str(dict_["topicId"])
        elif include_empty:
            instance.topic_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsChatSnapshots]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsChatSnapshots]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsChatSnapshots, List[ModelsChatSnapshots], Dict[Any, ModelsChatSnapshots]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "chatId": "chat_id",
            "createdAt": "created_at",
            "joinedTopics": "joined_topics",
            "messages": "messages",
            "namespace": "namespace",
            "senderId": "sender_id",
            "ticketId": "ticket_id",
            "topicId": "topic_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "chatId": True,
            "createdAt": True,
            "joinedTopics": True,
            "messages": True,
            "namespace": True,
            "senderId": True,
            "ticketId": True,
            "topicId": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsDictionaryUpdateRequest(Model):
    """Models dictionary update request (models.DictionaryUpdateRequest)

    Properties:
        false_negative: (falseNegative) REQUIRED List[str]

        false_positive: (falsePositive) REQUIRED List[str]

        word: (word) REQUIRED str

        word_type: (wordType) REQUIRED str
    """

    # region fields

    false_negative: List[str]  # REQUIRED
    false_positive: List[str]  # REQUIRED
    word: str  # REQUIRED
    word_type: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_false_negative(self, value: List[str]) -> ModelsDictionaryUpdateRequest:
        self.false_negative = value
        return self

    def with_false_positive(self, value: List[str]) -> ModelsDictionaryUpdateRequest:
        self.false_positive = value
        return self

    def with_word(self, value: str) -> ModelsDictionaryUpdateRequest:
        self.word = value
        return self

    def with_word_type(self, value: str) -> ModelsDictionaryUpdateRequest:
        self.word_type = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "false_negative"):
            result["falseNegative"] = [str(i0) for i0 in self.false_negative]
        elif include_empty:
            result["falseNegative"] = []
        if hasattr(self, "false_positive"):
            result["falsePositive"] = [str(i0) for i0 in self.false_positive]
        elif include_empty:
            result["falsePositive"] = []
        if hasattr(self, "word"):
            result["word"] = str(self.word)
        elif include_empty:
            result["word"] = ""
        if hasattr(self, "word_type"):
            result["wordType"] = str(self.word_type)
        elif include_empty:
            result["wordType"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        false_negative: List[str],
        false_positive: List[str],
        word: str,
        word_type: str,
        **kwargs,
    ) -> ModelsDictionaryUpdateRequest:
        instance = cls()
        instance.false_negative = false_negative
        instance.false_positive = false_positive
        instance.word = word
        instance.word_type = word_type
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsDictionaryUpdateRequest:
        instance = cls()
        if not dict_:
            return instance
        if "falseNegative" in dict_ and dict_["falseNegative"] is not None:
            instance.false_negative = [str(i0) for i0 in dict_["falseNegative"]]
        elif include_empty:
            instance.false_negative = []
        if "falsePositive" in dict_ and dict_["falsePositive"] is not None:
            instance.false_positive = [str(i0) for i0 in dict_["falsePositive"]]
        elif include_empty:
            instance.false_positive = []
        if "word" in dict_ and dict_["word"] is not None:
            instance.word = str(dict_["word"])
        elif include_empty:
            instance.word = ""
        if "wordType" in dict_ and dict_["wordType"] is not None:
            instance.word_type = str(dict_["wordType"])
        elif include_empty:
            instance.word_type = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsDictionaryUpdateRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsDictionaryUpdateRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsDictionaryUpdateRequest,
        List[ModelsDictionaryUpdateRequest],
        Dict[Any, ModelsDictionaryUpdateRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "falseNegative": "false_negative",
            "falsePositive": "false_positive",
            "word": "word",
            "wordType": "word_type",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "falseNegative": True,
            "falsePositive": True,
            "word": True,
            "wordType": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsPublicConfigResponse(Model):
    """Models public config response (models.PublicConfigResponse)

    Properties:
        chat_rate_limit_burst: (chatRateLimitBurst) REQUIRED int

        chat_rate_limit_duration: (chatRateLimitDuration) REQUIRED int

        general_rate_limit_burst: (generalRateLimitBurst) REQUIRED int

        general_rate_limit_duration: (generalRateLimitDuration) REQUIRED int

        max_chat_message_length: (maxChatMessageLength) REQUIRED int

        spam_chat_burst: (spamChatBurst) REQUIRED int

        spam_chat_duration: (spamChatDuration) REQUIRED int

        spam_mute_duration: (spamMuteDuration) REQUIRED int

        enable_pm_send_platform_id: (enablePmSendPlatformId) OPTIONAL bool
    """

    # region fields

    chat_rate_limit_burst: int  # REQUIRED
    chat_rate_limit_duration: int  # REQUIRED
    general_rate_limit_burst: int  # REQUIRED
    general_rate_limit_duration: int  # REQUIRED
    max_chat_message_length: int  # REQUIRED
    spam_chat_burst: int  # REQUIRED
    spam_chat_duration: int  # REQUIRED
    spam_mute_duration: int  # REQUIRED
    enable_pm_send_platform_id: bool  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_chat_rate_limit_burst(self, value: int) -> ModelsPublicConfigResponse:
        self.chat_rate_limit_burst = value
        return self

    def with_chat_rate_limit_duration(self, value: int) -> ModelsPublicConfigResponse:
        self.chat_rate_limit_duration = value
        return self

    def with_general_rate_limit_burst(self, value: int) -> ModelsPublicConfigResponse:
        self.general_rate_limit_burst = value
        return self

    def with_general_rate_limit_duration(
        self, value: int
    ) -> ModelsPublicConfigResponse:
        self.general_rate_limit_duration = value
        return self

    def with_max_chat_message_length(self, value: int) -> ModelsPublicConfigResponse:
        self.max_chat_message_length = value
        return self

    def with_spam_chat_burst(self, value: int) -> ModelsPublicConfigResponse:
        self.spam_chat_burst = value
        return self

    def with_spam_chat_duration(self, value: int) -> ModelsPublicConfigResponse:
        self.spam_chat_duration = value
        return self

    def with_spam_mute_duration(self, value: int) -> ModelsPublicConfigResponse:
        self.spam_mute_duration = value
        return self

    def with_enable_pm_send_platform_id(
        self, value: bool
    ) -> ModelsPublicConfigResponse:
        self.enable_pm_send_platform_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "chat_rate_limit_burst"):
            result["chatRateLimitBurst"] = int(self.chat_rate_limit_burst)
        elif include_empty:
            result["chatRateLimitBurst"] = 0
        if hasattr(self, "chat_rate_limit_duration"):
            result["chatRateLimitDuration"] = int(self.chat_rate_limit_duration)
        elif include_empty:
            result["chatRateLimitDuration"] = 0
        if hasattr(self, "general_rate_limit_burst"):
            result["generalRateLimitBurst"] = int(self.general_rate_limit_burst)
        elif include_empty:
            result["generalRateLimitBurst"] = 0
        if hasattr(self, "general_rate_limit_duration"):
            result["generalRateLimitDuration"] = int(self.general_rate_limit_duration)
        elif include_empty:
            result["generalRateLimitDuration"] = 0
        if hasattr(self, "max_chat_message_length"):
            result["maxChatMessageLength"] = int(self.max_chat_message_length)
        elif include_empty:
            result["maxChatMessageLength"] = 0
        if hasattr(self, "spam_chat_burst"):
            result["spamChatBurst"] = int(self.spam_chat_burst)
        elif include_empty:
            result["spamChatBurst"] = 0
        if hasattr(self, "spam_chat_duration"):
            result["spamChatDuration"] = int(self.spam_chat_duration)
        elif include_empty:
            result["spamChatDuration"] = 0
        if hasattr(self, "spam_mute_duration"):
            result["spamMuteDuration"] = int(self.spam_mute_duration)
        elif include_empty:
            result["spamMuteDuration"] = 0
        if hasattr(self, "enable_pm_send_platform_id"):
            result["enablePmSendPlatformId"] = bool(self.enable_pm_send_platform_id)
        elif include_empty:
            result["enablePmSendPlatformId"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        chat_rate_limit_burst: int,
        chat_rate_limit_duration: int,
        general_rate_limit_burst: int,
        general_rate_limit_duration: int,
        max_chat_message_length: int,
        spam_chat_burst: int,
        spam_chat_duration: int,
        spam_mute_duration: int,
        enable_pm_send_platform_id: Optional[bool] = None,
        **kwargs,
    ) -> ModelsPublicConfigResponse:
        instance = cls()
        instance.chat_rate_limit_burst = chat_rate_limit_burst
        instance.chat_rate_limit_duration = chat_rate_limit_duration
        instance.general_rate_limit_burst = general_rate_limit_burst
        instance.general_rate_limit_duration = general_rate_limit_duration
        instance.max_chat_message_length = max_chat_message_length
        instance.spam_chat_burst = spam_chat_burst
        instance.spam_chat_duration = spam_chat_duration
        instance.spam_mute_duration = spam_mute_duration
        if enable_pm_send_platform_id is not None:
            instance.enable_pm_send_platform_id = enable_pm_send_platform_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsPublicConfigResponse:
        instance = cls()
        if not dict_:
            return instance
        if "chatRateLimitBurst" in dict_ and dict_["chatRateLimitBurst"] is not None:
            instance.chat_rate_limit_burst = int(dict_["chatRateLimitBurst"])
        elif include_empty:
            instance.chat_rate_limit_burst = 0
        if (
            "chatRateLimitDuration" in dict_
            and dict_["chatRateLimitDuration"] is not None
        ):
            instance.chat_rate_limit_duration = int(dict_["chatRateLimitDuration"])
        elif include_empty:
            instance.chat_rate_limit_duration = 0
        if (
            "generalRateLimitBurst" in dict_
            and dict_["generalRateLimitBurst"] is not None
        ):
            instance.general_rate_limit_burst = int(dict_["generalRateLimitBurst"])
        elif include_empty:
            instance.general_rate_limit_burst = 0
        if (
            "generalRateLimitDuration" in dict_
            and dict_["generalRateLimitDuration"] is not None
        ):
            instance.general_rate_limit_duration = int(
                dict_["generalRateLimitDuration"]
            )
        elif include_empty:
            instance.general_rate_limit_duration = 0
        if (
            "maxChatMessageLength" in dict_
            and dict_["maxChatMessageLength"] is not None
        ):
            instance.max_chat_message_length = int(dict_["maxChatMessageLength"])
        elif include_empty:
            instance.max_chat_message_length = 0
        if "spamChatBurst" in dict_ and dict_["spamChatBurst"] is not None:
            instance.spam_chat_burst = int(dict_["spamChatBurst"])
        elif include_empty:
            instance.spam_chat_burst = 0
        if "spamChatDuration" in dict_ and dict_["spamChatDuration"] is not None:
            instance.spam_chat_duration = int(dict_["spamChatDuration"])
        elif include_empty:
            instance.spam_chat_duration = 0
        if "spamMuteDuration" in dict_ and dict_["spamMuteDuration"] is not None:
            instance.spam_mute_duration = int(dict_["spamMuteDuration"])
        elif include_empty:
            instance.spam_mute_duration = 0
        if (
            "enablePmSendPlatformId" in dict_
            and dict_["enablePmSendPlatformId"] is not None
        ):
            instance.enable_pm_send_platform_id = bool(dict_["enablePmSendPlatformId"])
        elif include_empty:
            instance.enable_pm_send_platform_id = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsPublicConfigResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsPublicConfigResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsPublicConfigResponse,
        List[ModelsPublicConfigResponse],
        Dict[Any, ModelsPublicConfigResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "chatRateLimitBurst": "chat_rate_limit_burst",
            "chatRateLimitDuration": "chat_rate_limit_duration",
            "generalRateLimitBurst": "general_rate_limit_burst",
            "generalRateLimitDuration": "general_rate_limit_duration",
            "maxChatMessageLength": "max_chat_message_length",
            "spamChatBurst": "spam_chat_burst",
            "spamChatDuration": "spam_chat_duration",
            "spamMuteDuration": "spam_mute_duration",
            "enablePmSendPlatformId": "enable_pm_send_platform_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "chatRateLimitBurst": True,
            "chatRateLimitDuration": True,
            "generalRateLimitBurst": True,
            "generalRateLimitDuration": True,
            "maxChatMessageLength": True,
            "spamChatBurst": True,
            "spamChatDuration": True,
            "spamMuteDuration": True,
            "enablePmSendPlatformId": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ModelsDictionary
from ..models import ModelsDictionaryExport
from ..models import ModelsDictionaryGroup
from ..models import ModelsDictionaryImportResult
from ..models import ModelsDictionaryInsertBulkRequest
from ..models import ModelsDictionaryInsertRequest
from ..models import ModelsDictionaryQueryResult
from ..models import ModelsDictionaryUpdateRequest
from ..models import RestapiErrorResponseBody

from ..operations.profanity import AdminProfanityCreate
from ..operations.profanity import AdminProfanityCreateBulk
from ..operations.profanity import AdminProfanityDelete
from ..operations.profanity import AdminProfanityExport
from ..operations.profanity import AdminProfanityGroup
from ..operations.profanity import AdminProfanityImport
from ..operations.profanity import (
    AdminProfanityImportActionEnum,
)
from ..operations.profanity import AdminProfanityQuery
from ..operations.profanity import AdminProfanityUpdate


@same_doc_as(AdminProfanityCreate)
def admin_profanity_create(
    body: ModelsDictionaryInsertRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin insert new profanity words (adminProfanityCreate)

    Insert new word for profanity censor

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary

        method: POST

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsDictionaryInsertRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsDictionary (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityCreate.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityCreate)
async def admin_profanity_create_async(
    body: ModelsDictionaryInsertRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin insert new profanity words (adminProfanityCreate)

    Insert new word for profanity censor

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary

        method: POST

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsDictionaryInsertRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsDictionary (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityCreate.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminProfanityCreateBulk)
def admin_profanity_create_bulk(
    body: ModelsDictionaryInsertBulkRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin bulk insert new profanity words (adminProfanityCreateBulk)

    Bulk insert new word for profanity censor

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/bulk

        method: POST

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsDictionaryInsertBulkRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityCreateBulk.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityCreateBulk)
async def admin_profanity_create_bulk_async(
    body: ModelsDictionaryInsertBulkRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin bulk insert new profanity words (adminProfanityCreateBulk)

    Bulk insert new word for profanity censor

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/bulk

        method: POST

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsDictionaryInsertBulkRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityCreateBulk.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminProfanityDelete)
def admin_profanity_delete(
    id_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete profanity words (adminProfanityDelete)

    Delete profanity words.

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/{id}

        method: DELETE

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityDelete.create(
        id_=id_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityDelete)
async def admin_profanity_delete_async(
    id_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete profanity words (adminProfanityDelete)

    Delete profanity words.

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/{id}

        method: DELETE

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityDelete.create(
        id_=id_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminProfanityExport)
def admin_profanity_export(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin export profanity words (adminProfanityExport)

    Export profanity words

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/export

        method: GET

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsDictionaryExport (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityExport.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityExport)
async def admin_profanity_export_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin export profanity words (adminProfanityExport)

    Export profanity words

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/export

        method: GET

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsDictionaryExport (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityExport.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminProfanityGroup)
def admin_profanity_group(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get profanity words group (adminProfanityGroup)

    Get profanity words group.

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/group

        method: GET

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - List[ModelsDictionaryGroup] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityGroup.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityGroup)
async def admin_profanity_group_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get profanity words group (adminProfanityGroup)

    Get profanity words group.

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/group

        method: GET

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - List[ModelsDictionaryGroup] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityGroup.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminProfanityImport)
def admin_profanity_import(
    file: Any,
    action: Optional[Union[str, AdminProfanityImportActionEnum]] = None,
    show_result: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin import profanity words (adminProfanityImport)

    Import profanity words

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/import

        method: POST

        tags: ["profanity"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) REQUIRED Any in form_data

        namespace: (namespace) REQUIRED str in path

        action: (action) OPTIONAL Union[str, ActionEnum] in query

        show_result: (showResult) OPTIONAL bool in query

    Responses:
        200: OK - ModelsDictionaryImportResult (returned when showResult=true)

        204: No Content - (No Content returned when showResult=false or not defined)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityImport.create(
        file=file,
        action=action,
        show_result=show_result,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityImport)
async def admin_profanity_import_async(
    file: Any,
    action: Optional[Union[str, AdminProfanityImportActionEnum]] = None,
    show_result: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin import profanity words (adminProfanityImport)

    Import profanity words

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/import

        method: POST

        tags: ["profanity"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        file: (file) REQUIRED Any in form_data

        namespace: (namespace) REQUIRED str in path

        action: (action) OPTIONAL Union[str, ActionEnum] in query

        show_result: (showResult) OPTIONAL bool in query

    Responses:
        200: OK - ModelsDictionaryImportResult (returned when showResult=true)

        204: No Content - (No Content returned when showResult=false or not defined)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityImport.create(
        file=file,
        action=action,
        show_result=show_result,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminProfanityQuery)
def admin_profanity_query(
    filter_mask: Optional[str] = None,
    include_children: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    parent_id: Optional[str] = None,
    start_with: Optional[str] = None,
    word_type: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query profanity words (adminProfanityQuery)

    Query all profanity words.

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary

        method: GET

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        filter_mask: (filterMask) OPTIONAL str in query

        include_children: (includeChildren) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        parent_id: (parentId) OPTIONAL str in query

        start_with: (startWith) OPTIONAL str in query

        word_type: (wordType) OPTIONAL str in query

    Responses:
        200: OK - ModelsDictionaryQueryResult (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityQuery.create(
        filter_mask=filter_mask,
        include_children=include_children,
        limit=limit,
        offset=offset,
        parent_id=parent_id,
        start_with=start_with,
        word_type=word_type,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityQuery)
async def admin_profanity_query_async(
    filter_mask: Optional[str] = None,
    include_children: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    parent_id: Optional[str] = None,
    start_with: Optional[str] = None,
    word_type: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin query profanity words (adminProfanityQuery)

    Query all profanity words.

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary

        method: GET

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        filter_mask: (filterMask) OPTIONAL str in query

        include_children: (includeChildren) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        parent_id: (parentId) OPTIONAL str in query

        start_with: (startWith) OPTIONAL str in query

        word_type: (wordType) OPTIONAL str in query

    Responses:
        200: OK - ModelsDictionaryQueryResult (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityQuery.create(
        filter_mask=filter_mask,
        include_children=include_children,
        limit=limit,
        offset=offset,
        parent_id=parent_id,
        start_with=start_with,
        word_type=word_type,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminProfanityUpdate)
def admin_profanity_update(
    body: ModelsDictionaryUpdateRequest,
    id_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin update profanity word (adminProfanityUpdate)

    Update profanity word

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/{id}

        method: PUT

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsDictionaryUpdateRequest in body

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsDictionary (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityUpdate.create(
        body=body,
        id_=id_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminProfanityUpdate)
async def admin_profanity_update_async(
    body: ModelsDictionaryUpdateRequest,
    id_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin update profanity word (adminProfanityUpdate)

    Update profanity word

    Properties:
        url: /chat/v1/admin/profanity/namespaces/{namespace}/dictionary/{id}

        method: PUT

        tags: ["profanity"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsDictionaryUpdateRequest in body

        id_: (id) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsDictionary (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Not Found)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminProfanityUpdate.create(
        body=body,
        id_=id_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Chat Service

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import ApiError, ApiResponse
from accelbyte_py_sdk.core import Operation
from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import HttpResponse
from accelbyte_py_sdk.core import deprecated

from ...models import RestapiErrorResponseBody


class AdminDeleteInboxMessage(Operation):
    """admin delete inbox message (adminDeleteInboxMessage)

    Delete inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/message/{messageId}

        method: DELETE

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        message_id: (messageId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        force: (force) OPTIONAL bool in query

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """

    # region fields

    _url: str = "/chat/v1/admin/inbox/namespaces/{namespace}/message/{messageId}"
    _path: str = "/chat/v1/admin/inbox/namespaces/{namespace}/message/{messageId}"
    _base_path: str = ""
    _method: str = "DELETE"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    service_name: Optional[str] = "chat"

    message_id: str  # REQUIRED in [path]
    namespace: str  # REQUIRED in [path]
    force: bool  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def path(self) -> str:
        return self._path

    @property
    def base_path(self) -> str:
        return self._base_path

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "message_id"):
            result["messageId"] = self.message_id
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "force"):
            result["force"] = self.force
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_message_id(self, value: str) -> AdminDeleteInboxMessage:
        self.message_id = value
        return self

    def with_namespace(self, value: str) -> AdminDeleteInboxMessage:
        self.namespace = value
        return self

    def with_force(self, value: bool) -> AdminDeleteInboxMessage:
        self.force = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "message_id") and self.message_id:
            result["messageId"] = str(self.message_id)
        elif include_empty:
            result["messageId"] = ""
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "force") and self.force:
            result["force"] = bool(self.force)
        elif include_empty:
            result["force"] = False
        return result

    # endregion to methods

    # region response methods

    class Response(ApiResponse):
        data_200: Optional[HttpResponse] = None
        error_400: Optional[RestapiErrorResponseBody] = None
        error_401: Optional[RestapiErrorResponseBody] = None
        error_403: Optional[RestapiErrorResponseBody] = None
        error_500: Optional[RestapiErrorResponseBody] = None

        def ok(self) -> AdminDeleteInboxMessage.Response:
            if self.error_400 is not None:
                err = self.error_400.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_401 is not None:
                err = self.error_401.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_403 is not None:
                err = self.error_403.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_500 is not None:
                err = self.error_500.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            return self

        def __iter__(self):
            if self.data_200 is not None:
                yield self.data_200
                yield None
            elif self.error_400 is not None:
                yield None
                yield self.error_400
            elif self.error_401 is not None:
                yield None
                yield self.error_401
            elif self.error_403 is not None:
                yield None
                yield self.error_403
            elif self.error_500 is not None:
                yield None
                yield self.error_500
            else:
                yield None
                yield self.error

    # noinspection PyMethodMayBeStatic
    def parse_response(self, code: int, content_type: str, content: Any) -> Response:
        """Parse the given response.

        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        result = AdminDeleteInboxMessage.Response()

        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )

        if error is not None:
            if not error.is_no_content():
                result.error = ApiError.create_from_http_response(error)
        else:
            code, content_type, content = pre_processed_response

            if code == 200:
                result.data_200 = HttpResponse.create(code, content)
            elif code == 400:
                result.error_400 = RestapiErrorResponseBody.create_from_dict(content)
                result.error = result.error_400.translate_to_api_error()
            elif code == 401:
                result.error_401 = RestapiErrorResponseBody.create_from_dict(content)
                result.error = result.error_401.translate_to_api_error()
            elif code == 403:
                result.error_403 = RestapiErrorResponseBody.create_from_dict(content)
                result.error = result.error_403.translate_to_api_error()
            elif code == 500:
                result.error_500 = RestapiErrorResponseBody.create_from_dict(content)
                result.error = result.error_500.translate_to_api_error()
            else:
                result.error = ApiError.create_from_http_response(
                    HttpResponse.create_undocumented_response(
                        code=code, content_type=content_type, content=content
                    )
                )

        result.status_code = str(code)
        result.content_type = content_type

        if 400 <= code <= 599 or result.error is not None:
            result.is_success = False

        return result

    # noinspection PyMethodMayBeStatic
    @deprecated
    def parse_response_x(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, HttpResponse], Union[None, HttpResponse, RestapiErrorResponseBody]
    ]:
        """Parse the given response.

        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return HttpResponse.create(code, "OK"), None
        if code == 400:
            return None, RestapiErrorResponseBody.create_from_dict(content)
        if code == 401:
            return None, RestapiErrorResponseBody.create_from_dict(content)
        if code == 403:
            return None, RestapiErrorResponseBody.create_from_dict(content)
        if code == 500:
            return None, RestapiErrorResponseBody.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls, message_id: str, namespace: str, force: Optional[bool] = None, **kwargs
    ) -> AdminDeleteInboxMessage:
        instance = cls()
        instance.message_id = message_id
        instance.namespace = namespace
        if force is not None:
            instance.force = force
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AdminDeleteInboxMessage:
        instance = cls()
        if "messageId" in dict_ and dict_["messageId"] is not None:
            instance.message_id = str(dict_["messageId"])
        elif include_empty:
            instance.message_id = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "force" in dict_ and dict_["force"] is not None:
            instance.force = bool(dict_["force"])
        elif include_empty:
            instance.force = False
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "messageId": "message_id",
            "namespace": "namespace",
            "force": "force",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "messageId": True,
            "namespace": True,
            "force": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: service-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Chat Service."""

__version__ = "0.4.42"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# config
from .wrappers import admin_get_all_config_v1
from .wrappers import admin_get_all_config_v1_async
from .wrappers import admin_get_config_v1
from .wrappers import admin_get_config_v1_async
from .wrappers import admin_get_log_config
from .wrappers import admin_get_log_config_async
from .wrappers import admin_patch_update_log_config
from .wrappers import admin_patch_update_log_config_async
from .wrappers import admin_update_config_v1
from .wrappers import admin_update_config_v1_async
from .wrappers import export_config
from .wrappers import export_config_async
from .wrappers import import_config
from .wrappers import import_config_async
from .wrappers import public_get_config_v1
from .wrappers import public_get_config_v1_async

# inbox
from .wrappers import admin_add_inbox_category
from .wrappers import admin_add_inbox_category_async
from .wrappers import admin_delete_inbox_category
from .wrappers import admin_delete_inbox_category_async
from .wrappers import admin_delete_inbox_message
from .wrappers import admin_delete_inbox_message_async
from .wrappers import admin_get_category_schema
from .wrappers import admin_get_category_schema_async
from .wrappers import admin_get_inbox_categories
from .wrappers import admin_get_inbox_categories_async
from .wrappers import admin_get_inbox_messages
from .wrappers import admin_get_inbox_messages_async
from .wrappers import admin_get_inbox_stats
from .wrappers import admin_get_inbox_stats_async
from .wrappers import admin_get_inbox_users
from .wrappers import admin_get_inbox_users_async
from .wrappers import admin_save_inbox_message
from .wrappers import admin_save_inbox_message_async
from .wrappers import admin_send_inbox_message
from .wrappers import admin_send_inbox_message_async
from .wrappers import admin_unsend_inbox_message
from .wrappers import admin_unsend_inbox_message_async
from .wrappers import admin_update_inbox_category
from .wrappers import admin_update_inbox_category_async
from .wrappers import admin_update_inbox_message
from .wrappers import admin_update_inbox_message_async

# moderation
from .wrappers import admin_delete_chat_snapshot
from .wrappers import admin_delete_chat_snapshot_async
from .wrappers import admin_get_chat_snapshot
from .wrappers import admin_get_chat_snapshot_async
from .wrappers import public_get_chat_snapshot
from .wrappers import public_get_chat_snapshot_async

# operations
from .wrappers import public_get_messages
from .wrappers import public_get_messages_async

# profanity
from .wrappers import admin_profanity_create
from .wrappers import admin_profanity_create_async
from .wrappers import admin_profanity_create_bulk
from .wrappers import admin_profanity_create_bulk_async
from .wrappers import admin_profanity_delete
from .wrappers import admin_profanity_delete_async
from .wrappers import admin_profanity_export
from .wrappers import admin_profanity_export_async
from .wrappers import admin_profanity_group
from .wrappers import admin_profanity_group_async
from .wrappers import admin_profanity_import
from .wrappers import admin_profanity_import_async
from .wrappers import admin_profanity_query
from .wrappers import admin_profanity_query_async
from .wrappers import admin_profanity_update
from .wrappers import admin_profanity_update_async

# topic
from .wrappers import admin_add_topic_member
from .wrappers import admin_add_topic_member_async
from .wrappers import admin_ban_topic_members
from .wrappers import admin_ban_topic_members_async
from .wrappers import admin_channel_topic_info
from .wrappers import admin_channel_topic_info_async
from .wrappers import admin_channel_topic_list
from .wrappers import admin_channel_topic_list_async
from .wrappers import admin_channel_topic_summary
from .wrappers import admin_channel_topic_summary_async
from .wrappers import admin_chat_history
from .wrappers import admin_chat_history_async
from .wrappers import admin_create_namespace_topic
from .wrappers import admin_create_namespace_topic_async
from .wrappers import admin_create_topic
from .wrappers import admin_create_topic_async
from .wrappers import admin_delete_chat
from .wrappers import admin_delete_chat_async
from .wrappers import admin_delete_topic
from .wrappers import admin_delete_topic_async
from .wrappers import admin_filter_chat_message
from .wrappers import admin_filter_chat_message_async
from .wrappers import admin_query_topic
from .wrappers import admin_query_topic_async
from .wrappers import admin_query_topic_log
from .wrappers import admin_query_topic_log_async
from .wrappers import admin_query_users_topic
from .wrappers import admin_query_users_topic_async
from .wrappers import admin_remove_topic_member
from .wrappers import admin_remove_topic_member_async
from .wrappers import admin_send_chat
from .wrappers import admin_send_chat_async
from .wrappers import admin_topic_chat_history
from .wrappers import admin_topic_chat_history_async
from .wrappers import admin_topic_list
from .wrappers import admin_topic_list_async
from .wrappers import admin_topic_members
from .wrappers import admin_topic_members_async
from .wrappers import admin_topic_shards
from .wrappers import admin_topic_shards_async
from .wrappers import admin_unban_topic_members
from .wrappers import admin_unban_topic_members_async
from .wrappers import admin_update_topic
from .wrappers import admin_update_topic_async
from .wrappers import public_ban_topic_members
from .wrappers import public_ban_topic_members_async
from .wrappers import public_chat_history
from .wrappers import public_chat_history_async
from .wrappers import public_delete_chat
from .wrappers import public_delete_chat_async
from .wrappers import public_get_muted_topics
from .wrappers import public_get_muted_topics_async
from .wrappers import public_mute_user
from .wrappers import public_mute_user_async
from .wrappers import public_topic_list
from .wrappers import public_topic_list_async
from .wrappers import public_unban_topic_members
from .wrappers import public_unban_topic_members_async
from .wrappers import public_unmute_user
from .wrappers import public_unmute_user_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ApiCreateTopicParams(Model):
    """Api create topic params (api.CreateTopicParams)

    Properties:
        admins: (admins) REQUIRED List[str]

        description: (description) REQUIRED str

        is_channel: (isChannel) REQUIRED bool

        is_joinable: (isJoinable) REQUIRED bool

        members: (members) REQUIRED List[str]

        name: (name) REQUIRED str

        type_: (type) REQUIRED str

        shard_limit: (shardLimit) OPTIONAL int
    """

    # region fields

    admins: List[str]  # REQUIRED
    description: str  # REQUIRED
    is_channel: bool  # REQUIRED
    is_joinable: bool  # REQUIRED
    members: List[str]  # REQUIRED
    name: str  # REQUIRED
    type_: str  # REQUIRED
    shard_limit: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_admins(self, value: List[str]) -> ApiCreateTopicParams:
        self.admins = value
        return self

    def with_description(self, value: str) -> ApiCreateTopicParams:
        self.description = value
        return self

    def with_is_channel(self, value: bool) -> ApiCreateTopicParams:
        self.is_channel = value
        return self

    def with_is_joinable(self, value: bool) -> ApiCreateTopicParams:
        self.is_joinable = value
        return self

    def with_members(self, value: List[str]) -> ApiCreateTopicParams:
        self.members = value
        return self

    def with_name(self, value: str) -> ApiCreateTopicParams:
        self.name = value
        return self

    def with_type(self, value: str) -> ApiCreateTopicParams:
        self.type_ = value
        return self

    def with_shard_limit(self, value: int) -> ApiCreateTopicParams:
        self.shard_limit = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "admins"):
            result["admins"] = [str(i0) for i0 in self.admins]
        elif include_empty:
            result["admins"] = []
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        if hasattr(self, "is_channel"):
            result["isChannel"] = bool(self.is_channel)
        elif include_empty:
            result["isChannel"] = False
        if hasattr(self, "is_joinable"):
            result["isJoinable"] = bool(self.is_joinable)
        elif include_empty:
            result["isJoinable"] = False
        if hasattr(self, "members"):
            result["members"] = [str(i0) for i0 in self.members]
        elif include_empty:
            result["members"] = []
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "type_"):
            result["type"] = str(self.type_)
        elif include_empty:
            result["type"] = ""
        if hasattr(self, "shard_limit"):
            result["shardLimit"] = int(self.shard_limit)
        elif include_empty:
            result["shardLimit"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        admins: List[str],
        description: str,
        is_channel: bool,
        is_joinable: bool,
        members: List[str],
        name: str,
        type_: str,
        shard_limit: Optional[int] = None,
        **kwargs,
    ) -> ApiCreateTopicParams:
        instance = cls()
        instance.admins = admins
        instance.description = description
        instance.is_channel = is_channel
        instance.is_joinable = is_joinable
        instance.members = members
        instance.name = name
        instance.type_ = type_
        if shard_limit is not None:
            instance.shard_limit = shard_limit
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiCreateTopicParams:
        instance = cls()
        if not dict_:
            return instance
        if "admins" in dict_ and dict_["admins"] is not None:
            instance.admins = [str(i0) for i0 in dict_["admins"]]
        elif include_empty:
            instance.admins = []
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        if "isChannel" in dict_ and dict_["isChannel"] is not None:
            instance.is_channel = bool(dict_["isChannel"])
        elif include_empty:
            instance.is_channel = False
        if "isJoinable" in dict_ and dict_["isJoinable"] is not None:
            instance.is_joinable = bool(dict_["isJoinable"])
        elif include_empty:
            instance.is_joinable = False
        if "members" in dict_ and dict_["members"] is not None:
            instance.members = [str(i0) for i0 in dict_["members"]]
        elif include_empty:
            instance.members = []
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "type" in dict_ and dict_["type"] is not None:
            instance.type_ = str(dict_["type"])
        elif include_empty:
            instance.type_ = ""
        if "shardLimit" in dict_ and dict_["shardLimit"] is not None:
            instance.shard_limit = int(dict_["shardLimit"])
        elif include_empty:
            instance.shard_limit = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiCreateTopicParams]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiCreateTopicParams]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiCreateTopicParams,
        List[ApiCreateTopicParams],
        Dict[Any, ApiCreateTopicParams],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "admins": "admins",
            "description": "description",
            "isChannel": "is_channel",
            "isJoinable": "is_joinable",
            "members": "members",
            "name": "name",
            "type": "type_",
            "shardLimit": "shard_limit",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "admins": True,
            "description": True,
            "isChannel": True,
            "isJoinable": True,
            "members": True,
            "name": True,
            "type": True,
            "shardLimit": False,
        }

    # endregion static methods
